@@ -1,6 +1,6 @@
 package WebService::Wikimapia::Polygon;
 
-$WebService::Wikimapia::Polygon::VERSION   = '0.13';
+$WebService::Wikimapia::Polygon::VERSION   = '0.14';
 $WebService::Wikimapia::Polygon::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ WebService::Wikimapia::Polygon - Placeholder for 'polygon' of L<WebService::Wiki
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
@@ -17,7 +17,7 @@ use 5.006;
 use Data::Dumper;
 
 use Moo;
-use namespace::clean;
+use namespace::autoclean;
 
 has 'x' => (is => 'ro');
 has 'y' => (is => 'ro');
